@@ -2,7 +2,7 @@
 # Nomade.pm
 # by Alain Barbet alian@alianwebserver.com
 # Copyright (C) 2000
-# $Id: Nomade.pm,v 1.2 2001/10/03 12:08:13 alian Exp $
+# $Id: Nomade.pm,v 1.3 2002/08/12 17:47:46 alian Exp $
 #
 
 package WWW::Search::Nomade;
@@ -10,52 +10,54 @@ require Exporter;
 @EXPORT = qw();
 @EXPORT_OK = qw();
 @ISA = qw(WWW::Search Exporter);
-$VERSION = ('$Revision: 1.2 $ ' =~ /(\d+\.\d+)/)[0];
+$VERSION = ('$Revision: 1.3 $ ' =~ /(\d+\.\d+)/)[0];
 
 use Carp ();
 use strict;
 use WWW::Search(qw (generic_option strip_tags));
 require WWW::SearchResult;
+use URI::URL;
 
 # private
-sub native_setup_search
-	{
-    	my($self, $native_query, $native_options_ref) = @_;
-    	$self->user_agent('alian');
-    	$self->{_next_to_retrieve} = 0;
-  	$self->{'search_base_url'} = 'http://rechercher.nomade.fr';  	
-	if (!defined($self->{_options})) {
-	$self->{_options} = 
-	  { 
-	   's' 	=> $native_query,
-	   'GL'     => "INTL",
-	   'ok.x'   => 1,
-         'ok.y'   => 1,
-	   'search_url' => $self->{'search_base_url'}.'/recherche.asp'
-        };}
-    	my($options_ref) = $self->{_options};
-    	if (defined($native_options_ref)) 
-    		{
-		# Copy in new options.
-		foreach (keys %$native_options_ref) 
-		  {$options_ref->{$_} = $native_options_ref->{$_};}
-    		}
-    	# Process the options.
-    	# (Now in sorted order for consistency regarless of hash ordering.)
-    	my($options) = '';
-    	foreach (sort keys %$options_ref) 
-    		{
-		# printf STDERR "option: $_ is " . $options_ref->{$_} . "\n";
-		next if (generic_option($_));
-		$options .= $_ . '=' . $options_ref->{$_} . '&' 
-		  if (defined $options_ref->{$_});
-    		}
+sub native_setup_search	{
+  my($self, $native_query, $native_options_ref) = @_;
+  $self->user_agent('WWW::Search::Nomade $VERSION');
+  $self->{_next_to_retrieve} = 0;
+  $self->{'search_base_url'} = 'http://rechercher.nomade.tiscali.fr';
+  if (!defined($self->{_options})) {
+    $self->{_options} = 
+      { 
+       's' 	=> $native_query,
+       'MT'     => $native_query,
+       'GL'     => "INTL",
+       'ok.x'   => 1,
+       'ok.y'   => 1,
+       'opt'    => 0,
+       'search_url' => $self->{'search_base_url'}.'/recherche.asp'
+      };}
+  my($options_ref) = $self->{_options};
+  if (defined($native_options_ref)) 
+    {
+      # Copy in new options.
+      foreach (keys %$native_options_ref) 
+	{$options_ref->{$_} = $native_options_ref->{$_};}
+    }
+  # Process the options.
+  # (Now in sorted order for consistency regarless of hash ordering.)
+  my($options) = '';
+  foreach (sort keys %$options_ref) 
+    {
+      # printf STDERR "option: $_ is " . $options_ref->{$_} . "\n";
+      next if (generic_option($_));
+      $options .= $_ . '=' . $options_ref->{$_} . '&' 
+	if (defined $options_ref->{$_});
+    }
 
-    	# Finally figure out the url.
-    	$self->{_base_url} = $self->{_next_url} 
-	  = $self->{_options}{'search_url'} ."?" . $options;
-    	print STDERR $self->{_base_url} . "\n" if ($self->{_debug});	
-	}
+  # Finally figure out the url.
+  $self->{_base_url} = $self->{_next_url} 
+    = $self->{_options}{'search_url'} ."?" . $options;
+  print STDERR $self->{_base_url} . "\n" if ($self->{_debug});	
+}
 
 # private
 sub create_hit
@@ -76,6 +78,7 @@ sub create_hit
 sub native_retrieve_some
   {
     my ($self) = @_;
+  $self->user_agent_delay(5);
     my($hits_found) = 0;
     my ($buf,$langue);
     print "DEBUG MODE\n" unless $self->{_debug}==0;
@@ -92,7 +95,7 @@ sub native_retrieve_some
 
     # parse the output
     my($HEADER, $HITS, $INHIT, $INLINK, $TRAILER, 
-	 $POST_NEXT, $FRANCO, $MONDIAL,$PREMIUM) = (1..10);  # order matters
+	 $POST_NEXT, $FRANCO, $MONDIAL,$PREMIUM) = (0..10);  # order matters
     my($state) = ($HEADER);
     my($raw) = '';
     foreach ($self->split_lines($response->content())) {#print $_,"\n";
@@ -108,11 +111,9 @@ sub native_retrieve_some
 	    print STDERR "No result\n"  if ($self->{_debug});
 	  }
 	elsif ($state == $HEADER &&
-		 m!<B>(\d+)</B> page\(s\)!)
-	  {
+		 m!<B>(\d*) page\(s\) web!)  {
 	    $self->approximate_result_count($1);
 	    $state = $HITS;
-	    $langue=$MONDIAL;
 	    print STDERR "$1 English result\n"  if $self->{_debug};
 	  }
 	elsif ($state == $HEADER &&
@@ -123,19 +124,18 @@ sub native_retrieve_some
 	    $langue=$FRANCO;
 	    print STDERR "More than 200 result.Premium\n"  if $self->{_debug};
 	  }
-	elsif ($state == $HEADER && m!(\d*) site\(s\) sur NOMADE\.FR!)
-	  {
-	    $self->approximate_result_count($1);
-	    $state = $HITS;
-	    $langue=$FRANCO;
-	    print STDERR "$1 French result\n"  if $self->{_debug};
-	  }
+	elsif ($state == $HEADER && m!(\d*) site\(s\) sur NOMADE\.FR! && $1) {
+	  $self->approximate_result_count($1);
+	  $state = $HITS;
+	  print STDERR "$1 French result\n"  if $self->{_debug};
+	}
 	######
 	# NEXT URL
 	#
-	elsif (m{<A HREF="([^\"]*?)"><B>Page suivante ></B></A>})
+	elsif (m{<A HREF="([^\"]*?)"><B>Page suivante </B></A>})
 	  {
 	    $self->{_next_url} = new URI::URL($1, $self->{_base_url});
+	    $self->http_referer($self->{'_next_url'});
 	    if ($self->{_next_url}!~/^http:\/\//) 
 		{$self->{_next_url}=$self->{'search_base_url'}.'/'.
 		   $self->{_next_url};}		
@@ -148,43 +148,22 @@ sub native_retrieve_some
 	elsif ($state!=$HEADER) {$buf.=$_."\n";}
     } # Fin du parcours par ligne
 
-    # If French search give no result, other pattern	
-    if ((defined $langue) && ($langue==$MONDIAL))
-	{	
-	  my @l=split(/<dl>/,$buf);
-	  foreach my $buf (@l)
-	    {
-		my ($url, $titre, $desc);
-		foreach (split(/\n/, $buf))
-		  {
-		    if (m!\t{4}<a HREF="(.*?)">(.*)</a>!)
-			{ $url = $1; $titre=$2; }
-		    elsif (m!^<small>(.*)!) { $desc = $1;}
-		    elsif (m!</dl>!)
-			{ $hits_found+=$self->create_hit($url,$titre,$desc); }
-		  }
-	    }	
+    my $sep = '<TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" '.
+      'CELLPADDING="0"><TR><TD HEIGHT="15"></TD></TR></TABLE>';
+    my @l=split(/$sep/,$buf);
+    print "I have $#l french parts\n" if $self->{_debug};
+    foreach my $buf (@l) {
+      my ($url, $titre, $desc);
+      foreach (split(/\n/, $buf)) {
+	if (m!<a \s TARGET="_blank" \s HREF="(.*)"><[bB]>(.*)</[bB]></a>.*
+	    <BR><SPAN \s CLASS="v-\d*">(.*)</SPAN><BR>!x) {
+	  $url = $1; $titre=$2; $desc = $3;
 	}
-    # French result
-    elsif (defined $langue && $langue==$FRANCO)
-	{
-	  my @l=split(/<dl>/,$buf);
-	  foreach my $buf (@l)
-	    {
-		my ($url, $titre, $desc);
-		foreach (split(/\n/, $buf))
-		  {
-		    if (m!<b>(\d*)\xa0-</b>\xa0\xa0
-			  <a \s target="_blank" \s HREF="(.*?)">
-			  .*<b><u>(.*)</u></b>!x)
-			{ $url = $2; $titre=$3; }
-		    elsif (m!^<small>(.*)<BR></small><small class="taille1"!) 
-			{ $desc = $1;}
-		    elsif (m!</dl>!)
-			{$hits_found+=$self->create_hit($url,$titre,$desc); }
-		  }
-	    }	
+	elsif ($url && m!</TABLE>!) {
+	  $hits_found+=$self->create_hit($url,$titre,$desc); 
 	}
+      }
+    }
     return $hits_found;
   }
 
